@@ -584,7 +584,7 @@ $(document).ready( function () {
 	);
 	
 	oTest.fnTest( 
-		"Initial sort occured",
+		"Initial sort occurred",
 		null,
 		function () { return $('#example tbody td:eq(0)').html() == "Gecko"; }
 	);
@@ -883,7 +883,7 @@ $(document).ready( function () {
 	);
 	
 	oTest.fnTest(
-		"Filter 'Win XP' - maintaing reverse sorting col 1",
+		"Filter 'Win XP' - maintaining reverse sorting col 1",
 		function () { $('#example_filter input').val("Win XP").keyup(); },
 		function () { return $('#example tbody tr:eq(0) td:eq(1)').html() == "Internet Explorer 7"; }
 	);
